package com.qianhe.service;

import java.util.List;
import com.qianhe.domain.SjGfjsLbzdbf;

/**
 * 规范建设-练兵指导帮扶Service接口
 * 
 * @author qianhe
 * @date 2025-08-19
 */
public interface ISjGfjsLbzdbfService 
{
    /**
     * 查询规范建设-练兵指导帮扶
     * 
     * @param id 规范建设-练兵指导帮扶主键
     * @return 规范建设-练兵指导帮扶
     */
    public SjGfjsLbzdbf selectSjGfjsLbzdbfById(Long id);

    /**
     * 查询规范建设-练兵指导帮扶列表
     * 
     * @param sjGfjsLbzdbf 规范建设-练兵指导帮扶
     * @return 规范建设-练兵指导帮扶集合
     */
    public List<SjGfjsLbzdbf> selectSjGfjsLbzdbfList(SjGfjsLbzdbf sjGfjsLbzdbf);

    /**
     * 新增规范建设-练兵指导帮扶
     * 
     * @param sjGfjsLbzdbf 规范建设-练兵指导帮扶
     * @return 结果
     */
    public int insertSjGfjsLbzdbf(SjGfjsLbzdbf sjGfjsLbzdbf);

    /**
     * 修改规范建设-练兵指导帮扶
     * 
     * @param sjGfjsLbzdbf 规范建设-练兵指导帮扶
     * @return 结果
     */
    public int updateSjGfjsLbzdbf(SjGfjsLbzdbf sjGfjsLbzdbf);

    /**
     * 批量删除规范建设-练兵指导帮扶
     * 
     * @param ids 需要删除的规范建设-练兵指导帮扶主键集合
     * @return 结果
     */
    public int deleteSjGfjsLbzdbfByIds(Long[] ids);

    /**
     * 删除规范建设-练兵指导帮扶信息
     * 
     * @param id 规范建设-练兵指导帮扶主键
     * @return 结果
     */
    public int deleteSjGfjsLbzdbfById(Long id);
}
